from setuptools import setup

setup(name='bgprob_distributions',
      version='0.1',
      description='Gaussian and Binomila distributions',
      packages=['bgprob_distributions'],
      author='Vinit Kumar',
      author_email='vinit_kumarin@yahoo.com',
      zip_safe=False)
